@@ -59,7 +59,6 @@ int romedacaddr = 0;
 int romedacaddr_set = 0;
 int romsize_given = 0;
 int sparcleon0 = 0;
-int sparcleon0rom = 0;
     
 #ifndef TOOLBASE
 #define TOOLBASE "/opt/mkprom2"
@@ -87,7 +86,6 @@ int verbose = 0;
 int vverbose = 0;
 int leon = 1;
 double freq = 0;
-int romres = 0;
 int comp = 1;
 int flash = 0;
 int entry[16] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
@@ -100,6 +98,7 @@ char ofile[128] = "prom.out";
 enum {
     MULTIFLAG_FLAT  = 0x01,
     MULTIFLAG_SOFT  = 0x04,
+    MULTIFLAG_NOLIB = 0x08
 };
 /*
  * multiflags: Bit mask with MULTIFLAG_x values
@@ -107,7 +106,7 @@ enum {
  */
 static const char *get_multidir(unsigned int multiflags);
 
-char *ccprefix = "sparc-elf";
+char *ccprefix = "sparc-gaisler-elf";
 int ccprefixdo = 0;
 char *prefix = TOOLBASE;
     
@@ -150,6 +149,11 @@ static inline void trysystem(const char *command)
 {
   int ret;
 
+  if (command == NULL) {
+        printf("MKPROM2 WARNING: no command supplied to system()\n");
+        return;
+  }
+
   ret = system(command);
   if (0 == ret) {
     return;
@@ -315,7 +319,12 @@ int main (argc, argv)
     sprintf(lynxoshome_pre,"%s/cdk/mkprom2/",lynxoshome);
     prefix = lynxoshome_pre;
 #endif    
-    
+
+#ifdef CCPREFIX
+    ccprefix = CCPREFIX;
+    ccprefixdo = 1;
+#endif
+
     printf ("MKPROM %s - boot image generator for LEON applications\n", version);
     printf ("Copyright Cobham Gaisler AB 2004-2017, all rights reserved.\n\n");
 	if (argc < 2)
@@ -802,11 +811,6 @@ int main (argc, argv)
 				romcs = rombanks;
 			}
 		  }
-                else if (strcmp (argv[stat], "-sparcleon0rom") == 0)
-                  {
-                      sparcleon0 = 1;
-                      sparcleon0rom = 1;
-                  }
 		else if (strcmp (argv[stat], "-sparcleon0") == 0)
                   {
                       sparcleon0 = 1;
@@ -952,10 +956,6 @@ int main (argc, argv)
 		  {
 		      checksvt = 1;
 		  }
-		else if (strcmp (argv[stat], "-romres") == 0)
-		  {
-		      romres = 1;
-		  }
 		else if (strcmp (argv[stat], "-qsvt") == 0) {
 		    qsvt = 1;
 		    goto copyxlist;
@@ -1036,6 +1036,9 @@ int main (argc, argv)
 		uartnr++;
 	}
 
+#ifdef NO_MULTILIB
+    multiflags = MULTIFLAG_NOLIB;
+#endif
     multidir = get_multidir(multiflags);
     if (NULL == multidir) {
         printf ("ERROR: Could not determine mkprom2 multi-lib dir: Check the GCC -m* options.\n");
@@ -1575,7 +1578,7 @@ int main (argc, argv)
 
 /* 	  ################# UART ####################### */
 	  
-	  tmp = (((10 * (long long) freq) / (8 * baud)) - 5) / 10;
+	  tmp = (((10 * (long) freq) / (8 * baud)) - 5) / 10;
 	  baud = freq / (8 * (tmp + 1));
 	  fprintf (dumpfile, "_uart:\n");
 	  fprintf (dumpfile, "\t.word\t0x%08x\n", tmp);
@@ -1617,7 +1620,7 @@ int main (argc, argv)
 	  if (sdramsz)
 	      tmp = (refr << 12);
 	  fprintf (dumpfile, "_memcfg3:\n");
-	  if (edac) tmp |= 0x200;  // enable RAM EDAC
+	  if (edac) tmp |= 0x200;  /* enable RAM EDAC */
 	  if (memcfg3_on)
 		  tmp = memcfg3;
 	  fprintf (dumpfile, "\t.word\t0x%x\n", tmp);
@@ -1657,15 +1660,13 @@ int main (argc, argv)
 	  
 	  tmp |= ((i & 0x7) << 10) | (tmp2 & 0x3);
 
-	  //printf("Decoded memsz : 0x%x\n", (256 * 1024) << ((tmp >> 10) & 7));
-	  
 	  fprintf (dumpfile, "_memcfg1:\n");
 	  if (memcfg1_on)
 		  tmp = memcfg1;
 
 	  fprintf (dumpfile, "\t.word\t0x%x\n", tmp);
 	  
-	  tmp = (((10 * (long long) freq) / (32 * baud)) - 5) / 10;
+	  tmp = (((10 * (long) freq) / (32 * baud)) - 5) / 10;
 	  baud = freq / (32 * (tmp + 1));
 	  
 	  fprintf (dumpfile, "_uart:\n");
@@ -1794,7 +1795,7 @@ int main (argc, argv)
     prefix = strlen(prefix) ? prefix : "." ;
     
     if(!ccprefixdo) {
-        static char ccprefixes[5][20] = {"sparc-elf", "sparc-gaisler-elf",
+        static char ccprefixes[5][20] = {"sparc-gaisler-elf", "sparc-gaisler-rtems5",
                                          "sparc-rtems", "sparc-rcc-rtems4.12",
                                          "sparc-linux"};
         int prefix_count = NELEM(ccprefixes);
@@ -1822,32 +1823,6 @@ int main (argc, argv)
     sprintf(lscriptpath, "%s/%s%s", 
             prefix, ecos ? "linkpromecos" : (erc32 ? "linkpromerc32" : "linkprom") , flash ? "flash" : "");
     lscriptpathdel[0] = 0;
-    if (flash && sparcleon0) {
-        FILE *file = 0, *file2 = 0;
-        printf("Rewrite %s\n",lscriptpath);
-	if ((file = fopen (lscriptpath, "rb"))) {
-            char l[512], lscriptpath2[512];
-            lscriptpath2[0] = 0;
-            strcat(lscriptpath2,"sparcleon0.in.prom");
-            if ((file2 = fopen (lscriptpath2, "w"))) {
-                while(fgets(l, sizeof(l), file)) {
-                    if (strstr(l,"rom") && strstr(l,"0x00000000") && strstr(l,"ORIGIN") && strstr(l,"LENGTH")) {
-                        fprintf(file2, "  rom     : ORIGIN = 0x%08x, LENGTH = 1024M\n", startaddr);
-                    } else if (strstr(l,"ram") && strstr(l,"0x40000000") && strstr(l,"ORIGIN") && strstr(l,"LENGTH")) {
-                        fprintf(file2, "  ram     : ORIGIN = 0x00000000, LENGTH = 1024M\n");
-                    } else {
-                        fputs(l, file2);
-                    }
-                }
-                lscriptpath[0] = 0;
-                lscriptpathdel[0] = 0;
-                strcat(lscriptpath, lscriptpath2);
-                strcat(lscriptpathdel, lscriptpath2);
-            }
-        }
-        if (file) fclose(file);
-        if (file2) fclose(file2);
-    }
     
     sprintf (cmd,
 	     "%s-gcc%s -O2 -g -N -T%s -Ttext=0x%x  "
@@ -1977,33 +1952,15 @@ int main (argc, argv)
     
     if (vverbose)
       strcat (cmd, " -v -Wl,-verbose -Wl,-M ");
-    if (flash) {
-	/* if (ecos) { */
-/* 	    strcat (cmd, " -lmkprom2ecos "); */
-/* 	} else { */
-/* 	    strcat (cmd, " -lmkprom2 "); */
-/* 	} */
-/*       strcat (cmd, " -lleonbare -qprom2 dump.s "); */
+    if (mp)
       strcat (cmd, " dump.s ");
-      strcat (cmd, flist);
-      strcat (cmd, " -e start ");
-    }
-    else if (mp)
 /*       strcat (cmd, " -lmkprom3mp -lleonbare dump.s "); */
-      strcat (cmd, " dump.s ");
     else
-/*       strcat (cmd, " -lmkprom3 -lleonbare dump.s "); */
       strcat (cmd, " dump.s ");
+/*       strcat (cmd, " -lmkprom3 -lleonbare dump.s "); */
     if (bdinit)
 	strcat (cmd, "bdinit.o ");
-    if (flash) {
-/*       if (ecos) { */
-/* 	strcat (cmd, " -qprom2ecos -qnocrtbegin -qnocrtn -lm -o "); */
-/*       } else { */
-	strcat (cmd, " -lm -o ");
-/*       } */
-    }
-    else if (mp)
+    if (mp)
 /*       strcat (cmd, " -lmkprom3mp -o "); */
       strcat (cmd, " -o ");
     else
@@ -2019,11 +1976,11 @@ int main (argc, argv)
     {
       fflush(stdout);
 #ifdef __MINGW32__
-      system("del dump.s");
-      system("del xdump.s");
+      trysystem("del dump.s");
+      trysystem("del xdump.s");
 #else
-      system ("rm -f dump.s");
-      system ("rm -f xdump.s");
+      trysystem ("rm -f dump.s");
+      trysystem ("rm -f xdump.s");
 #endif
       if (strlen(lscriptpathdel)) {
           char c[1024];
@@ -2032,75 +1989,9 @@ int main (argc, argv)
 #else
           sprintf(c, "rm -f %s", lscriptpathdel);
 #endif
-          system(c);
+          trysystem(c);
       }
     }
-    if (flash) {
-        /* change rom load addresses of <ofile> */
-        flash = 2;
-        {
-            /* implementaion using binary extraction */
-            char *b;
-#ifdef WIN32
-            flashld = fopen (flashldn, "wb");
-#else
-            flashld = fopen (flashldn, "w");
-#endif
-            if (flashld) {
-                fprintf(flashld,"OUTPUT_FORMAT(\"elf32-sparc\", \"elf32-sparc\", \"elf32-sparc\")\n");
-                fprintf(flashld,"OUTPUT_ARCH(sparc)\n");
-                
-            }
-
-            /* create a copy that holds the symbols */
-#ifdef __MINGW32__
-            sprintf(cmd, "copy %s %s.sym", ofile, ofile);
-#else
-            sprintf(cmd, "cp %s %s.sym", ofile, ofile);
-#endif
-            if (verbose)
-              printf("%s\n", cmd);
-            fflush(stdout);
-            system (cmd);
-
-            /* traverse into the image, extract all sections and append linkerscript line so <flashldn> */
-            entry[0] = elf_load (ofile);
-
-            /* close linkerscript */
-            fprintf(flashld,"\n}\n");
-            fclose(flashld);
-            flashld = 0;
-            if ((b = malloc(512*(flashsectionspos+1)))) {
-                /* link everything together */
-                sprintf(b,"%s-ld%s -o %s -T%s ",ccprefix,postfix,ofile,flashldn);
-                for (i = 0; i < flashsectionspos; i++) {
-                    strcat(b," ");
-                    strcat(b,(const char *)flashsections[i]);
-                }
-                if (verbose) {
-                  printf("%s\n", b);
-                }
-                fflush(stdout);
-                trysystem (b);
-                free(b);
-                /* clear temporary files */
-                if (!dump) {
-                    for (i = 0; i < flashsectionspos; i++) {
-                        
-#ifdef __MINGW32__
-                        sprintf(cmd,"del %s\n",flashsections[i]);
-#else
-                        sprintf(cmd,"rm -f %s\n",flashsections[i]);
-#endif
-                        if (verbose)
-                          printf("%s\n", cmd);
-                        fflush(stdout);
-                        system (cmd);
-                    }
-                }
-            }
-        }
-    }
     if (dobch8) {
 	    appendbch8(".bch8",1, SEEK_END, startaddr + romsize);
     } else if (dobch8q) {
@@ -2134,12 +2025,10 @@ void usage (char *argv0)
 	 puts("Mkprom General Options");
 	 puts("  -baud <baudrate>\tSet rate of UART A to baudrate. Default value is 19200.");
 	 puts("  -bdinit\t\tCall the functions bdinit1() and bdinit2() in file\n\t\t\tbdinit.o during startup. See manual.");
-//	 puts("\tThe user can optionally call two user-defined routines, bdinit1() and bdinit2(), during  the boot process. bdinit1() is called after the LEON registers have been initialized but before the memory has been cleared. bdinit2() is called after the memory has been initialized but before the application is loaded. Note that when bdinit1() is called, the stack has not been setup meaning that bdinit1() must be a leaf routine and not allocate any stack space (no local variables). When -bdinit is used, a file called bdinit.o must exist in the current directory, containing the two routines.");
 	 puts("  -dump\t\t\tThe intermediate assembly code with the compressed\n\t\t\tapplication and the LEON register values is put in dump.s\n\t\t\t(only for debugging of mkprom).");
 	 puts("  -freq <mhz>\t\tDefines the system clock in MHz. This value is used to\n\t\t\tcalculate the divider value for the baud rate generator\n\t\t\tand timers.");
 	 puts("  -noinit\t\tSuppress all code which initializes on-chip peripherals\n\t\t\tsuch as uarts, timers and memory controllers. This option\n\t\t\trequires -bdinit to add custom initialisation code,\n\t\t\tor the boot process will fail.");
 	 puts("  -nomsg\t\tSuppress the boot message.");
-	 puts("  -romres\t\tCreate ROM resident image.");
 	 puts("  -nocomp\t\tDon't compress application. Decreases loading time\n\t\t\ton the expense of rom size.");
 	 puts("  -o <outfile>\t\tPut the resulting image in outfile,\n\t\t\trather then prom.out (default).");
 	 puts("  -stack <addr>\t\tSets the initial stack pointer to addr.\n\t\t\tIf not specified, the stack starts at top-of-ram.");
@@ -2151,13 +2040,12 @@ void usage (char *argv0)
 	 puts("  -agga4\t\tGenerate an image for AGGA4.");
 	 puts("  -erc32\t\tGenerate an image for ERC32.");
 
-	 puts("\nMkprom options for the LEON2 memory controller");
+	 puts("\nMkprom options for the LEON2/3/4/5 memory controllers");
 	 puts("  -cas <delay>\t\tSet the SDRAM CAS delay. Allowed values are 2 and 3,\n\t\t\t2 is default.");
 	 puts("  -col <bits>\t\tSet the number of SDRAM column bits.\n\t\t\tAllowed values are 8 - 11, 9 is default.");
 	 puts("  -nosram\t\tDisables the static RAM and maps SDRAM at\n\t\t\taddress 0x40000000.");
 	 puts("  -ramsize <size>\tDefines the total available RAM. Used to initialize\n\t\t\tmemory configuration register(s) and stack calculation.\n\t\t\tThe default value is 2048 (2 Mbyte).");
 	 puts("  -ramcs <chip_selects>\tSet the number of ram banks to chip_selects.\n\t\t\tDefault is 1.");
-	 puts("  -romws <ws>\t\tSet the PROM read and write wait states parameter. Default is 15.");
 	 puts("  -ramws <ws>\t\tSet the SRAM read and write wait states parameter. Default is 3.");
 	 puts("  -ramrws <ws>\t\tSet the SRAM  read wait states parameter. Default is 3.");
 	 puts("  -ramwws <ws>\t\tSet the SRAM write wait states parameter. Default is 3.");
@@ -2165,6 +2053,8 @@ void usage (char *argv0)
 	 puts("  -rmw\t\t\tPerform read-modify-write cycles during byte\n\t\t\tand halfword writes.");
 	 puts("  -sdram <size>\t\tThe amount of attached SDRAM in Mbyte. 0 by default");
 	 puts("  -sdrambanks <num_banks> Set the number of populated SDRAM banks.\n\t\t\tDefault is 1.");
+	 puts("  -romws <ws>\t\tSet the PROM read and write wait states parameter. Default is 15.");
+	 puts("  -romsize <size>\tSet total size of the PROM in kByte. Default is 0x80000.");
 	 puts("  -trfc <delay>\t\tSet the SDRAM tRFC parameter (in ns). Default is 66 ns.");
 	 puts("  -trp <delay>\t\tSet the SDRAM tRP parameter (in ns). Default is 20 ns.");
 	 puts("  -refresh <period>\tSet the SDRAM refresh period (in us). Default is 7.8 us.");
@@ -2222,7 +2112,7 @@ int
 PutPacketInfo (buf)
      char *buf;
 {
-    packet_header PH;
+    packet_header PH = {0};
 
     PH.MAGIC = MAGIC_NUMBER;
     PH.PARAMS = (unsigned char) (((N >> 6) & 0xf0) |
@@ -2534,87 +2424,12 @@ int
 dumpsec (char *buf, int section_address, int section_size,
 	 char *section_name, FILE * dumpfile)
 {
-    char cmd[512];
     char *lzss_buf;
-    char *postfix = OS_EXESUFFIX;
 
-    if ((secnum == 0) && (section_address == 0) && !(sparcleon0 && !sparcleon0rom))
-      {
-        if (!romres) {
-            fprintf(stderr, "WARNING: Unexpected section address 0. Use -romres to create ROM resident image.\n");
-        }
-	printf("Section in rom detected, switching off compression\n");
-	  comp = 0;
-	  flash = 1;
-    } else if ((secnum == 0) && (section_address != 0)){
-        if (romres) {
-            fprintf(stderr, "WARNING: Option -romres expects section address 0.\n");
-        }
-    }
-    if (flash) {
-        if (flash == 2) {
-                /* extract a section and convert to elf */
-                /* 1: extract section to binary <f>.b */
-                sprintf(cmd, "%s-objcopy%s --output-target=binary --only-section=%s %s %s%s.b",ccprefix,postfix,section_name, ofile, ofile, section_name);
-                if (verbose) {
-                  printf("%s\n", cmd);
-                }
-                fflush(stdout);
-                trysystem (cmd);
-                /* 2: convert binary <f>.b to elf <f>.b.elf.data with .data section */
-                sprintf(cmd, "%s-ld%s -r -b binary %s%s.b -o %s%s.b.elf.data  ", ccprefix,postfix,ofile,section_name,ofile,section_name);
-                if (verbose) {
-                  printf("%s\n", cmd);
-                }
-                fflush(stdout);
-                trysystem (cmd);
-                /* 3: rename .data to .data.<sectioname> */
-                sprintf(cmd, "%s-objcopy%s --rename-section .data=.data%s %s%s.b.elf.data %s%s.b.elf",ccprefix,postfix,section_name,ofile,section_name,ofile,section_name);
-                if (verbose) {
-                  printf("%s\n", cmd);
-                }
-                fflush(stdout);
-                trysystem (cmd);
-                
-                if (!dodump) {
-                    
-#ifdef __MINGW32__
-                    sprintf(cmd,"del %s%s.b\n",ofile, section_name);
-#else
-                    sprintf(cmd,"rm -f %s%s.b\n",ofile, section_name);
-#endif
-                    if (verbose)
-                      printf("%s\n", cmd);
-                    fflush(stdout);
-                    system (cmd);
-                }
-
-                /* assume that .text always come first */
-                if (strcmp(".text", section_name) == 0)
-                    foffset = section_address;
-                
-                if (flashld) {
-                    char b[512];
-                    sprintf(b,"%s%s.b.elf",ofile,section_name);
-                    if (strcmp(".text", section_name) == 0) {
-                        fprintf(flashld,"ENTRY(start)\n");
-                        fprintf(flashld,"SECTIONS \n{\n");
-                        fprintf(flashld,". = 0x%x;\n",foffset);
-                        fprintf(flashld,"start = .;\n");
-                    } else {
-                        fprintf(flashld,". = 0x%x;\n",foffset);
-                    }
-                    fprintf(flashld,"%s : { *(.data%s) }\n",section_name,section_name);
-                    flashsections[flashsectionspos] = strdup((const char *)b);
-                    flashsectionspos++;
-                }
-                foffset += section_size;
-        }
-        secnum++;
-        return(0);
-    } else {
-        fprintf (dumpfile, "\t .text\n");
+    if ((secnum == 0) && (section_address == 0) && (sparcleon0 == 0)) {
+        fprintf(stderr, "WARNING: Unexpected section address 0. -romres no longer supported.\n");
     }
+    fprintf (dumpfile, "\t .text\n");
     checkseci(secnum);
     secarr[secnum].paddr = section_address;
     secarr[secnum].len = section_size;
@@ -2813,12 +2628,10 @@ ldelf (FILE * fp, FILE * dumpfile)
 			((sh.sh_addr+sh.sh_size) <= (ph[k].p_vaddr + ph[k].p_filesz))) {
 */
 		    vaddr = sh.sh_addr;
-//		    sh.sh_addr = sh.sh_addr  - ph[k].p_vaddr + ph[k].p_paddr;
 		    sh.sh_addr = sh.sh_offset  - ph[k].p_offset + ph[k].p_paddr;
 	            if ((verbose) && (vaddr != sh.sh_addr)) {
 		      	printf( "relocating %s (%d): %08x -> %08x\n", &strtab[sh.sh_name], k, vaddr, sh.sh_addr); 
 		    }
-//		    sprintf(tdebug, "%08x (%08x)\n", sh.sh_addr, ph[k].p_paddr; dprint(tdebug);
 		    break;
 		}
 	    }
@@ -3074,22 +2887,22 @@ void appendbch8(char *post, int rev, int set, int pos )
                         fflush(stdout);
 #ifdef __MINGW32__
                         sprintf (cmd, "del %s", ofn);
-                        system(cmd);
+                        trysystem(cmd);
                         sprintf (cmd, "del %s", ofnw);
-                        system(cmd);
+                        trysystem(cmd);
                         sprintf (cmd, "del %s", bfn);
-                        system(cmd);
+                        trysystem(cmd);
                         sprintf (cmd, "del %s", bfnw);
-                        system(cmd);
+                        trysystem(cmd);
 #else
                         sprintf (cmd, "rm -f %s", ofn);
-                        system(cmd);
+                        trysystem(cmd);
                         sprintf (cmd, "rm -f %s", ofnw);
-                        system(cmd);
+                        trysystem(cmd);
                         sprintf (cmd, "rm -f %s", bfn);
-                        system(cmd);
+                        trysystem(cmd);
                         sprintf (cmd, "rm -f %s", bfnw);
-                        system(cmd);
+                        trysystem(cmd);
 #endif
                     }
 
@@ -3099,16 +2912,16 @@ void appendbch8(char *post, int rev, int set, int pos )
 	}
 }
 
-// BCH code
+/* BCH code */
 int bch (long int word)
 {
    int i, c=0;
    int cb[8], d[32];
 
-   // expand bit values from word
+   /* expand bit values from word */
    for (i=0; i <= 31; i++) d[i] = (word >> i) & 0x1;
 
-   // check sum
+   /* check sum */
    cb[0] = d[0] ^ d[4] ^ d[6] ^ d[7] ^ d[8] ^ d[9] ^ d[11] ^ d[14] ^ d[17] ^ d[18] ^ d[19] ^ d[21] ^ d[26] ^ d[28] ^ d[29] ^ d[31];
    cb[1] = d[0] ^ d[1] ^ d[2] ^ d[4] ^ d[6] ^ d[8] ^ d[10] ^ d[12] ^ d[16] ^ d[17] ^ d[18] ^ d[20] ^ d[22] ^ d[24] ^ d[26] ^ d[28];
    cb[2] = ~(d[0] ^ d[3] ^ d[4] ^ d[7] ^ d[9] ^ d[10] ^ d[13] ^ d[15] ^ d[16] ^ d[19] ^ d[20] ^ d[23] ^ d[25] ^ d[26] ^ d[29] ^ d[31]);
@@ -3117,7 +2930,7 @@ int bch (long int word)
    cb[5] = d[8] ^ d[9] ^ d[10] ^ d[11] ^ d[12] ^ d[13] ^ d[14] ^ d[15] ^ d[24] ^ d[25] ^ d[26] ^ d[27] ^ d[28] ^ d[29] ^ d[30] ^ d[31];
    cb[6] = d[0] ^ d[1] ^ d[2] ^ d[3] ^ d[4] ^ d[5] ^ d[6] ^ d[7] ^ d[24] ^ d[25] ^ d[26] ^ d[27] ^ d[28] ^ d[29] ^ d[30] ^ d[31];
 
-   // compress bit values from byte
+   /* compress bit values from byte */
    for (i=0; i < 7; i++) c |= ((cb[i] & 0x1) << i);
 
    return c;
@@ -3133,6 +2946,7 @@ static const struct multientry multientries[] = {
     {MULTIFLAG_SOFT                             , "/lib/ut699_soft"},
     {                     MULTIFLAG_FLAT        , "/lib/ut699_flat"},
     {MULTIFLAG_SOFT     | MULTIFLAG_FLAT        , "/lib/ut699_soft_flat"},
+    {MULTIFLAG_NOLIB                            , "/lib"},
 };
 
 static const char *get_multidir(unsigned int multiflags)
